BuilderOptions class

Options that are passed to a BuilderFactory to instantiate a Builder.

Based on these options the Builder can change any aspect of its behavior: its Builder.buildExtensions, which files it reads, which files it outputs and/or the contents of those files.

The options come from three places: a builder's own build.yaml file can define defaults; the package the builder is running in can set options; and options can be passed in on the build_runner command line using --define.

Constructors

BuilderOptions(Map<String, dynamic> config, {bool isRoot = false})
const

Properties

config Map<String, dynamic>
The configuration to apply to a given usage of a Builder.
final
hashCode int
The hash code for this object.
no setterinherited
isRoot bool
Whether this builder is running on the root package.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideWith(BuilderOptions? other) BuilderOptions
Returns a new set of options with keys from other overriding options in this instance.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const BuilderOptions
A configuration with no options set.
forRoot → const BuilderOptions
A configuration with isRoot set to true and no options set.