config property

Map<String, dynamic> config
final

The configuration to apply to a given usage of a Builder.

Possible values are primitives available in JSON and yaml: String, num, bool or List or Map of these types.

Implementation

final Map<String, dynamic> config;