build library
Classes
- AssetId
-
A file in a
build_runnerbuild. - AssetReader
- The "read" part of the BuildStep API.
- AssetWriter
- The "write" part of the BuildStep API.
- Builder
-
A builder in the
build_runnerbuild. - BuilderOptions
- Options that are passed to a BuilderFactory to instantiate a Builder.
- BuildStep
-
A single step in
build_runnerbuild. - FileDeletingBuilder
- A PostProcessBuilder which can be configured to consume any input extensions and always deletes it primary input.
- PostProcessBuilder
- A builder which runs in a special phase at the end of the build.
- PostProcessBuildStep
- A simplified BuildStep which can only read its primary input, and can't get a Resolver or any Resources.
- ReleasableResolver
- A resolver that should be manually released at the end of a build step.
- Resolver
- Standard interface for resolving Dart source code as part of a build.
- Resolvers
- A factory that returns a resolver for a given BuildStep.
-
Resource<
T> - A handle to create and cleanup some expensive object based on a lifecycle defined by the build system.
- ResourceManager
- Manages fetching and disposing of a group of Resources.
Extensions
- BuildOutputExtensions on Builder
- Extensions on Builder describing expected outputs.
Properties
- log → Logger
-
Loggerfor use by a builder to log to the mainbuild_runneroutput.no setter
Functions
-
expectedOutputs(
Builder builder, AssetId input) → Iterable< AssetId> -
Collects the expected AssetIds created by
builderwhen giveninputbased on the extension configuration.
Typedefs
-
BeforeExit
= FutureOr<
void> Function() - BuilderFactory = Builder Function(BuilderOptions options)
-
A factory for a builder in the
build_runnerbuild. -
CreateInstance<
T> = FutureOr< T> Function() -
DisposeInstance<
T> = FutureOr< void> Function(T instance) - PostProcessBuilderFactory = PostProcessBuilder Function(BuilderOptions)
Exceptions / Errors
- AssetNotFoundException
- BuildStepCompletedException
- InvalidInputException
- InvalidOutputException
- NonLibraryAssetException
- Thrown when attempting to read a non-Dart library in a Resolver.
- PackageNotFoundException
- SyntaxErrorInAssetException
- Exception thrown by a resolver when attempting to resolve a Dart library with syntax errors.
- UnexpectedOutputException
- UnresolvableAssetException