canRead abstract method
Indicates whether id can be read by this build step.
A file can be read if it exists as an input or was generated by a builder that runs before the current builder.
Outputs from builders that run after the current builder cannot be read,
even if they already exist in the artifact tree or at their package path
from an earlier build. For such files, canRead returns false and the
read methods will throw AssetNotFoundException.
Implementation
@override
Future<bool> canRead(AssetId id);